Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/simpleini.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'snippets.cpp')
-rw-r--r--snippets.cpp9
1 files changed, 7 insertions, 2 deletions
diff --git a/snippets.cpp b/snippets.cpp
index e2295fe..8a69aa6 100644
--- a/snippets.cpp
+++ b/snippets.cpp
@@ -101,8 +101,13 @@ snippets(
// DELETING DATA
- // deleting a key from a section. Optionally the entire
- // section may be deleted if it is now empty.
+ // deleting a key with a value from a section.
+ // Optionally the entire section may be deleted if
+ // it is now empty.
+ ini.DeleteValue("section-name", "key-name", "value",
+ true /*delete the section if empty*/);
+
+ // deleting a key with any value from a section.
ini.Delete("section-name", "key-name",
true /*delete the section if empty*/);